==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkPiecewiseFunctionShiftScale.java <==
// java wrapper for vtkPiecewiseFunctionShiftScale object
//

package vtk;
import vtk.*;

public class vtkPiecewiseFunctionShiftScale extends vtkPiecewiseFunctionAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPositionShift_2(double id0);
  public void SetPositionShift(double id0)
    { SetPositionShift_2(id0); }

  private native void SetPositionScale_3(double id0);
  public void SetPositionScale(double id0)
    { SetPositionScale_3(id0); }

  private native void SetValueShift_4(double id0);
  public void SetValueShift(double id0)
    { SetValueShift_4(id0); }

  private native void SetValueScale_5(double id0);
  public void SetValueScale(double id0)
    { SetValueScale_5(id0); }

  private native double GetPositionShift_6();
  public double GetPositionShift()
    { return GetPositionShift_6(); }

  private native double GetPositionScale_7();
  public double GetPositionScale()
    { return GetPositionScale_7(); }

  private native double GetValueShift_8();
  public double GetValueShift()
    { return GetValueShift_8(); }

  private native double GetValueScale_9();
  public double GetValueScale()
    { return GetValueScale_9(); }

  public vtkPiecewiseFunctionShiftScale() { super(); }

  public vtkPiecewiseFunctionShiftScale(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkPiecewiseFunctionShiftScale.java <==
// java wrapper for vtkPiecewiseFunctionShiftScale object
//

package vtk;
import vtk.*;

public class vtkPiecewiseFunctionShiftScale extends vtkPiecewiseFunctionAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPositionShift_2(double id0);
  public void SetPositionShift(double id0)
    { SetPositionShift_2(id0); }

  private native void SetPositionScale_3(double id0);
  public void SetPositionScale(double id0)
    { SetPositionScale_3(id0); }

  private native void SetValueShift_4(double id0);
  public void SetValueShift(double id0)
    { SetValueShift_4(id0); }

  private native void SetValueScale_5(double id0);
  public void SetValueScale(double id0)
    { SetValueScale_5(id0); }

  private native double GetPositionShift_6();
  public double GetPositionShift()
    { return GetPositionShift_6(); }

  private native double GetPositionScale_7();
  public double GetPositionScale()
    { return GetPositionScale_7(); }

  private native double GetValueShift_8();
  public double GetValueShift()
    { return GetValueShift_8(); }

  private native double GetValueScale_9();
  public double GetValueScale()
    { return GetValueScale_9(); }

  public vtkPiecewiseFunctionShiftScale() { super(); }

  public vtkPiecewiseFunctionShiftScale(long id) { super(id); }
  public native long   VTKInit();

}
